| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
NationStates.RateLimit
Description
Simple rate limiting combinator.
Documentation
Create a new rate limiter with the specified delay.
The rate limiter is thread-safe, and can be shared between threads.
nationstates-0.2.0.2: NationStates API client
| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
NationStates.RateLimit
Description
Simple rate limiting combinator.
Create a new rate limiter with the specified delay.
The rate limiter is thread-safe, and can be shared between threads.